==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.rest.client/src/com/openexchange/rest/client/endpointpool/internal/EndpointManagerFactoryImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.rest.client.endpointpool.internal;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.TimeUnit;
import org.apache.http.client.HttpClient;
import com.openexchange.exception.OXException;
import com.openexchange.rest.client.endpointpool.EndpointAvailableStrategy;
import com.openexchange.rest.client.endpointpool.EndpointManager;
import com.openexchange.rest.client.endpointpool.EndpointManagerFactory;
import com.openexchange.server.ServiceExceptionCode;
import com.openexchange.server.ServiceLookup;
import com.openexchange.timer.TimerService;


/**
 * {@link EndpointManagerFactoryImpl}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.1
 */
public class EndpointManagerFactoryImpl implements EndpointManagerFactory {

    private final ServiceLookup services;

    /**
     * Initializes a new {@link EndpointManagerFactoryImpl}.
     */
    public EndpointManagerFactoryImpl(ServiceLookup services) {
        super();
        this.services = services;
    }

    @Override
    public EndpointManager createEndpointManagerByUris(List<URI> endpointUris, HttpClient httpClient, EndpointAvailableStrategy availableStrategy, long heartbeatInterval, TimeUnit timeUnit) throws OXException {
        TimerService timerService = services.getOptionalService(TimerService.class);
        if (null == timerService) {
            throw ServiceExceptionCode.absentService(TimerService.class);
        }

        return new EndpointManagerImpl(endpointUris, httpClient, availableStrategy, timeUnit.toMillis(heartbeatInterval), timerService);
    }

    @Override
    public EndpointManager createEndpointManager(List<String> endpoints, HttpClient httpClient, EndpointAvailableStrategy availableStrategy, long heartbeatInterval, TimeUnit timeUnit) throws OXException {
        TimerService timerService = services.getOptionalService(TimerService.class);
        if (null == timerService) {
            throw ServiceExceptionCode.absentService(TimerService.class);
        }

        if (null == endpoints) {
            throw new IllegalArgumentException("End-points must not be null");
        }

        int size = endpoints.size();
        if (size == 0) {
            throw new IllegalArgumentException("End-points must not be empty");
        }

        try {
            List<URI> endpointUris = new ArrayList<URI>(size);
            for (String sEndpoint : endpoints) {
                endpointUris.add(new URI(sEndpoint.endsWith("/") ? sEndpoint.substring(0, sEndpoint.length() - 1) : sEndpoint));
            }

            return new EndpointManagerImpl(endpointUris, httpClient, availableStrategy, timeUnit.toMillis(heartbeatInterval), timerService);
        } catch (URISyntaxException e) {
            throw new IllegalArgumentException("Invalid URIs", e);
        }
    }

}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.rest.client/src/com/openexchange/rest/client/endpointpool/internal/EndpointManagerFactoryImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.rest.client.endpointpool.internal;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.TimeUnit;
import com.openexchange.exception.OXException;
import com.openexchange.rest.client.endpointpool.EndpointAvailableStrategy;
import com.openexchange.rest.client.endpointpool.EndpointManager;
import com.openexchange.rest.client.endpointpool.EndpointManagerFactory;
import com.openexchange.rest.client.httpclient.HttpClientService;
import com.openexchange.server.ServiceExceptionCode;
import com.openexchange.server.ServiceLookup;
import com.openexchange.timer.TimerService;


/**
 * {@link EndpointManagerFactoryImpl}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.1
 */
public class EndpointManagerFactoryImpl implements EndpointManagerFactory {

    private final HttpClientService httpClientService;
    private final ServiceLookup services;

    /**
     * Initializes a new {@link EndpointManagerFactoryImpl}.
     *
     * @param httpClientService The HTTP client service to use
     * @param services The service look-up to obtain needed OSGi services
     */
    public EndpointManagerFactoryImpl(HttpClientService httpClientService, ServiceLookup services) {
        super();
        this.httpClientService = httpClientService;
        this.services = services;
    }

    @Override
    public EndpointManager createEndpointManagerByUris(List<URI> endpointUris, String httpClientId, EndpointAvailableStrategy availableStrategy, long heartbeatInterval, TimeUnit timeUnit) throws OXException {
        TimerService timerService = services.getOptionalService(TimerService.class);
        if (null == timerService) {
            throw ServiceExceptionCode.absentService(TimerService.class);
        }

        return new EndpointManagerImpl(endpointUris, httpClientId, availableStrategy, timeUnit.toMillis(heartbeatInterval), timerService, httpClientService);
    }

    @Override
    public EndpointManager createEndpointManager(List<String> endpoints, String httpClientId, EndpointAvailableStrategy availableStrategy, long heartbeatInterval, TimeUnit timeUnit) throws OXException {
        TimerService timerService = services.getOptionalService(TimerService.class);
        if (null == timerService) {
            throw ServiceExceptionCode.absentService(TimerService.class);
        }

        if (null == endpoints) {
            throw new IllegalArgumentException("End-points must not be null");
        }

        int size = endpoints.size();
        if (size == 0) {
            throw new IllegalArgumentException("End-points must not be empty");
        }

        try {
            List<URI> endpointUris = new ArrayList<URI>(size);
            for (String sEndpoint : endpoints) {
                endpointUris.add(new URI(sEndpoint.endsWith("/") ? sEndpoint.substring(0, sEndpoint.length() - 1) : sEndpoint));
            }

            return new EndpointManagerImpl(endpointUris, httpClientId, availableStrategy, timeUnit.toMillis(heartbeatInterval), timerService, httpClientService);
        } catch (URISyntaxException e) {
            throw new IllegalArgumentException("Invalid URIs", e);
        }
    }

}
